@@ -5,10 +5,22 @@ use dirs::config_dir;
 use serde::Deserialize;
 
 #[derive(Deserialize, PartialEq, Eq, Debug)]
-pub struct CMakeLintConfig {
+pub struct Config {
     pub command_upcase: String,
     pub enable_external_cmake_lint: bool,
     pub line_max_words: usize,
+    pub format: FormatConfig,
+}
+
+impl Default for Config {
+    fn default() -> Self {
+        Self {
+            command_upcase: "ignore".to_string(),
+            enable_external_cmake_lint: false,
+            line_max_words: 80,
+            format: FormatConfig::default(),
+        }
+    }
 }
 
 pub struct LintSuggestion {
@@ -50,59 +62,46 @@ impl Default for LintSuggestion {
     }
 }
 
-impl Default for CMakeLintConfig {
-    fn default() -> Self {
-        Self {
-            command_upcase: "ignore".to_string(),
-            enable_external_cmake_lint: false,
-            line_max_words: 80,
-        }
-    }
+#[derive(Default, Deserialize, PartialEq, Eq, Debug)]
+pub struct FormatConfig {
+    pub program: Option<String>,
+    pub args: Vec<String>,
 }
 
-fn find_user_config() -> Option<PathBuf> {
-    let mut path = std::env::current_dir().unwrap(); // should never fail
-    path = path.join(".neocmakelint.toml");
+fn find_config_file() -> Option<PathBuf> {
+    let current_dir = std::env::current_dir().ok()?;
 
-    if path.exists() {
-        tracing::info!("Using project-level config file: {:?}", path);
-        return Some(path);
-    };
-
-    if let Some(mut path) = config_dir() {
-        path = path.join("neocmakelsp").join("lint.toml");
+    for file in [".neocmake.toml", ".neocmakelint.toml"] {
+        let path = current_dir.join(file);
         if path.exists() {
-            tracing::info!("Using user-level config file: {:?}", path);
+            tracing::info!("Using project-level config file: {:?}", path);
             return Some(path);
         }
-    };
+    }
+
+    if let Some(config_dir) = config_dir() {
+        for file in ["config.toml", "lint.toml"] {
+            let path = config_dir.join("neocmakelsp").join(file);
+            if path.exists() {
+                tracing::info!("Using user-level config file: {:?}", path);
+                return Some(path);
+            }
+        }
+    }
 
     None
 }
 
-pub static CMAKE_LINT_CONFIG: LazyLock<CMakeLintConfig> = LazyLock::new(|| {
-    if let Some(path) = find_user_config() {
-        if let Ok(buf) = std::fs::read_to_string(path) {
-            if let Ok(config) = toml::from_str::<CMakeLintConfig>(&buf) {
-                return config;
-            };
-        };
-    };
+pub static CONFIG: LazyLock<Config> = LazyLock::new(|| {
+    if let Some(path) = find_config_file()
+        && let Ok(buf) = std::fs::read_to_string(path)
+        && let Ok(config) = toml::from_str::<Config>(&buf)
+    {
+        return config;
+    }
 
-    CMakeLintConfig::default()
+    Config::default()
 });
 
 pub static CMAKE_LINT: LazyLock<LintSuggestion> =
-    LazyLock::new(|| CMAKE_LINT_CONFIG.command_upcase.clone().into());
-
-#[cfg(test)]
-mod tests {
-    use crate::config::CMAKE_LINT_CONFIG;
-
-    #[test]
-    fn tst_lint_config() {
-        assert_eq!(CMAKE_LINT_CONFIG.command_upcase, "ignore");
-        assert!(!CMAKE_LINT_CONFIG.enable_external_cmake_lint);
-        assert_eq!(CMAKE_LINT_CONFIG.line_max_words, 80);
-    }
-}
+    LazyLock::new(|| CONFIG.command_upcase.clone().into());
