@@ -87,12 +87,11 @@ pub fn scanner_include_defs(
     find_cmake_in_package: bool,
     is_builtin: bool,
 ) -> Option<Vec<CacheDataUnit>> {
-    if is_builtin {
-        if let Ok(cache) = PACKAGE_COMPLETE_CACHE.lock() {
-            if let Some(complete_items) = cache.get(path) {
-                return Some(complete_items.clone());
-            }
-        }
+    if is_builtin
+        && let Ok(cache) = PACKAGE_COMPLETE_CACHE.lock()
+        && let Some(complete_items) = cache.get(path)
+    {
+        return Some(complete_items.clone());
     }
     let content = fs::read_to_string(path).ok()?;
     let mut parse = tree_sitter::Parser::new();
@@ -111,10 +110,10 @@ pub fn scanner_include_defs(
     if !is_builtin {
         return result_data;
     }
-    if let Some(ref content) = result_data {
-        if let Ok(mut cache) = PACKAGE_COMPLETE_CACHE.lock() {
-            cache.insert(path.clone(), content.clone());
-        }
+    if let Some(ref content) = result_data
+        && let Ok(mut cache) = PACKAGE_COMPLETE_CACHE.lock()
+    {
+        cache.insert(path.clone(), content.clone());
     }
     result_data
 }
@@ -186,10 +185,10 @@ pub fn scanner_package_defs(
     include_files: &mut Vec<PathBuf>,
     complete_packages: &mut Vec<String>,
 ) -> Option<Vec<CacheDataUnit>> {
-    if let Ok(cache) = PACKAGE_COMPLETE_CACHE.lock() {
-        if let Some(complete_items) = cache.get(path) {
-            return Some(complete_items.clone());
-        }
+    if let Ok(cache) = PACKAGE_COMPLETE_CACHE.lock()
+        && let Some(complete_items) = cache.get(path)
+    {
+        return Some(complete_items.clone());
     }
     let content = fs::read_to_string(path).ok()?;
     let mut parse = tree_sitter::Parser::new();
@@ -205,10 +204,10 @@ pub fn scanner_package_defs(
         false,
         true,
     );
-    if let Some(ref content) = result_data {
-        if let Ok(mut cache) = PACKAGE_COMPLETE_CACHE.lock() {
-            cache.insert(path.clone(), content.clone());
-        }
+    if let Some(ref content) = result_data
+        && let Ok(mut cache) = PACKAGE_COMPLETE_CACHE.lock()
+    {
+        cache.insert(path.clone(), content.clone());
     }
     result_data
 }
