@@ -8,7 +8,8 @@ use tower_lsp::lsp_types::{
 };
 
 use crate::CMakeNodeKinds;
-use crate::{consts::TREESITTER_CMAKE_LANGUAGE, utils::treehelper::ToPosition};
+use crate::consts::TREESITTER_CMAKE_LANGUAGE;
+use crate::utils::treehelper::ToPosition;
 
 static LINT_REGEX: LazyLock<Regex> =
     LazyLock::new(|| Regex::new(r#"((?<length>\d+)/(?<max>\d+))"#).unwrap());
@@ -16,7 +17,7 @@ static LINT_REGEX: LazyLock<Regex> =
 #[test]
 fn lint_regex_text() {
     let information = "[C0301] Line too long (92/80)";
-    let caps = LINT_REGEX.captures(&information).unwrap();
+    let caps = LINT_REGEX.captures(information).unwrap();
     assert_eq!(&caps["length"], "92");
     assert_eq!(&caps["max"], "80");
 }
