@@ -1,4 +1,5 @@
-use std::{collections::HashMap, path::Path};
+use std::collections::HashMap;
+use std::path::Path;
 
 use tower_lsp::lsp_types::{Location, Position, TextEdit, Uri, WorkspaceEdit};
 
