@@ -10,8 +10,6 @@ use super::{
 use crate::Uri;
 use crate::utils::{CMakePackage, CMakePackageFrom, PackageType};
 
-pub(super) const LIBS: [&str; 4] = ["lib", "lib32", "lib64", "share"];
-
 pub static CMAKE_PACKAGES: LazyLock<Vec<CMakePackage>> =
     LazyLock::new(|| get_cmake_message().into_values().collect());
 
@@ -50,10 +48,10 @@ pub(super) fn get_cmake_message_with_prefixes(
                 if CMAKECONFIG.is_match(f.to_str().unwrap()) {
                     ispackage = true;
                 }
-                if CMAKECONFIGVERSION.is_match(f.to_str().unwrap()) {
-                    if let Ok(context) = fs::read_to_string(&f) {
-                        version = get_version(&context);
-                    }
+                if CMAKECONFIGVERSION.is_match(f.to_str().unwrap())
+                    && let Ok(context) = fs::read_to_string(&f)
+                {
+                    version = get_version(&context);
                 }
             }
 
@@ -74,10 +72,9 @@ pub(super) fn get_cmake_message_with_prefixes(
             if let Some(config_file_location) = tojump
                 .iter()
                 .position(|file| CMAKECONFIG.is_match(file.to_str().unwrap()))
+                && config_file_location != 0
             {
-                if config_file_location != 0 {
-                    tojump.swap(0, config_file_location);
-                }
+                tojump.swap(0, config_file_location);
             }
             let location = Uri::from_file_path(&path).unwrap();
 
@@ -117,10 +114,10 @@ pub(super) fn get_cmake_message_with_prefixes(
                             let filename = path_name.to_str().unwrap();
                             if CMAKEREGEX.is_match(filename) {
                                 tojump.push(filepath.clone());
-                                if CMAKECONFIGVERSION.is_match(filename) {
-                                    if let Ok(context) = fs::read_to_string(&filepath) {
-                                        version = get_version(&context);
-                                    }
+                                if CMAKECONFIGVERSION.is_match(filename)
+                                    && let Ok(context) = fs::read_to_string(&filepath)
+                                {
+                                    version = get_version(&context);
                                 }
                             }
                         }
@@ -139,10 +136,9 @@ pub(super) fn get_cmake_message_with_prefixes(
             if let Some(config_file_location) = tojump
                 .iter()
                 .position(|file| CMAKECONFIG.is_match(file.to_str().unwrap()))
+                && config_file_location != 0
             {
-                if config_file_location != 0 {
-                    tojump.swap(0, config_file_location);
-                }
+                tojump.swap(0, config_file_location);
             }
 
             if let Some(captures) = SPECIAL_PACKAGE_PATTERN.captures(&packagename.clone()) {
